@@ -1235,7 +1235,7 @@ App::App(const synfig::String& basepath, int *argc, char ***argv):
 	if (!g_thread_supported())
 		Glib::thread_init();
 
-	distance_system=Distance::SYSTEM_UNITS;
+	distance_system=Distance::SYSTEM_PIXELS;
 
 	if(mkdir(synfigapp::Main::get_user_app_directory().c_str(),ACCESSPERMS)<0)
 	{
@@ -1756,7 +1756,7 @@ App::add_recent_file(const std::string &file_name, const std::string &window_siz
 	return;
 }
 
-static Time::Format _App_time_format(Time::FORMAT_NORMAL);
+static Time::Format _App_time_format(Time::FORMAT_FRAMES);
 
 Time::Format
 App::get_time_format()
@@ -2276,7 +2276,8 @@ App::dialog_save_file(const std::string &title, std::string &filename, std::stri
 	{
 		file_type_enum = manage(new Widget_Enum());
 		file_type_enum->set_param_desc(ParamDesc().set_hint("enum")
-				.add_enum_value(synfig::RELEASE_VERSION_0_64_2, "0.64.2", strprintf("0.64.2 (%s)", _("current")))
+				.add_enum_value(synfig::RELEASE_VERSION_0_64_3, "0.64.3", strprintf("0.64.3 (%s)", _("current")))
+				.add_enum_value(synfig::RELEASE_VERSION_0_64_2, "0.64.2", "0.64.2")
 				.add_enum_value(synfig::RELEASE_VERSION_0_64_1, "0.64.1", "0.64.1")
 				.add_enum_value(synfig::RELEASE_VERSION_0_64_0, "0.64.0", "0.64.0")
 				.add_enum_value(synfig::RELEASE_VERSION_0_63_04, "0.63.05", "0.63.05")
